/******************************************************************************
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Orignal Author: Pawel Sosulski <pawel@sosulski.net>
******************************************************************************/

const GLib = imports.gi.GLib;
const GObject = imports.gi.GObject;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Lib = Me.imports.convenience;
const SETTINGS_SCHEMA = "org.gnome.shell.extensions.icinga-checker";
const USERNAMEENTRY = "username";
const PASSWORDENTRY = "password";
const URLCGIENTRY = "urlcgi";
const URLTYPEENTRY = "urltype";
const TIMEOUTINTERVALENTRY = "timeoutinterval";

function init(){}


const IcingaCheckerSettingsWidget = new GObject.Class({
    Name: 'IcingaChecker.Prefs.Widget',
    GTypeName: 'IcingaCheckerSettingsWidget',
    Extends: Gtk.Box,

    _init: function(params) {
        this.parent(params);

        this.orientation = Gtk.Orientation.VERTICAL;
        this.spacign = 0;

        // creates the settings
        this.settings = Lib.getSettings(SETTINGS_SCHEMA);

        // creates the ui builder and add the main resource file
        let uiFilePath = Me.path + "/ui/prefs-dialog.gtkbuilder";
        let builder = new Gtk.Builder();

        if (builder.add_from_file(uiFilePath) == 0) {
            global.log("JS LOG: could not load the ui file: %s".format(uiFilePath));

            let label = new Gtk.Label({
                label: _("Could not load the preferences UI file"),
                vexpand: true
            });

            this.pack_start(label, true, true, 0);
        } else {
            global.log('JS LOG:_UI file receive and load: '+uiFilePath);

            let mainContainer = builder.get_object("main-gtkbox1");

            this.pack_start(mainContainer, true, true, 0);
            
            let usernameEntry = builder.get_object("username");
            let passwordEntry = builder.get_object("password");
            let urlcgiEntry = builder.get_object("urlcgi");
            let urltypeEntry = builder.get_object("urltype");
            let timeoutIntervalEntry = builder.get_object("timeoutinterval");
            
            this.settings.bind(USERNAMEENTRY,usernameEntry , "text", Gio.SettingsBindFlags.DEFAULT);
            this.settings.bind(PASSWORDENTRY,passwordEntry , "text", Gio.SettingsBindFlags.DEFAULT);
            this.settings.bind(URLCGIENTRY,urlcgiEntry , "text", Gio.SettingsBindFlags.DEFAULT);
            this.settings.bind(URLTYPEENTRY,urltypeEntry , "active", Gio.SettingsBindFlags.DEFAULT);
            this.settings.bind(TIMEOUTINTERVALENTRY,timeoutIntervalEntry , "active", Gio.SettingsBindFlags.DEFAULT);
        }
    }
});


function buildPrefsWidget() {
    let widget = new IcingaCheckerSettingsWidget();
    widget.show_all();

    return widget;
}
